.message-card {
    min-height: 25px;
}

.raw-icons img {
   height: 22px;
    width: 22px;
}


.datetime {
    margin-bottom: 10px;
    color: #999;
    font-size: 13px;
    white-space:nowrap;
}

.raw-message
{
	font-size:13px;
	width:100%;
}

.raw-icons
{white-space: nowrap;}

// For the pygmentized json blobs
.highlight {
    -moz-border-radius: 15px;
    border-radius: 15px;
}
